@@ -4,6 +4,7 @@ This is the main the command line interface to xyz_py
 
 import argparse
 import numpy as np
+import os
 
 from . import xyz_py
 
@@ -27,7 +28,7 @@ def struct_info_func(args):
 
     labels = xyz_py.add_numbers(labels)
 
-    f_head = args.xyz_file.split(".")[0]
+    f_head = os.path.splitext(args.xyz_f_name)[0]
 
     if args.cutoffs:
         cutoffs = parse_cutoffs(args.cutoffs)
@@ -69,6 +70,36 @@ def struct_info_func(args):
     return
 
 
+def rotate_func(args):
+    """
+    Wrapper for cli call to rotate
+
+    Parameters
+    ----------
+        args : argparser object
+            command line arguments
+
+    Returns
+    -------
+        None
+
+    """
+    labels, coords = xyz_py.load_xyz(args.xyz_file)
+
+    xyz_py.rotate_coords(coords, args.alpha, args.beta, args.gamma)
+
+    if args.out_f_name:
+        out_f_name = args.out_f_name
+    else:
+        out_f_name = "{}_rotated.xyz".format(
+            os.path.splitext(args.xyz_file)[0]
+        )
+
+    xyz_py.save_xyz(out_f_name, labels, coords)
+
+    return
+
+
 def list_form_func(args):
     """
     Wrapper for cli call to find_entities
