@@ -15,120 +15,31 @@ import sys
 from collections import defaultdict
 import deprecation
 
-__version__ = "4.2.0"
+__version__ = "4.3.0"
 
 # Dictionary of relative atomic masses
 ram_dict = {
-    "H": 1.0076,
-    "He": 4.0026,
-    "Li": 6.941,
-    "Be": 9.0122,
-    "B": 10.811,
-    "C": 12.0107,
-    "N": 14.0067,
-    "O": 15.9994,
-    "F": 18.9984,
-    "Ne": 20.1797,
-    "Na": 22.9897,
-    "Mg": 24.305,
-    "Al": 26.9815,
-    "Si": 28.0855,
-    "P": 30.9738,
-    "S": 32.065,
-    "Cl": 35.453,
-    "K": 39.0983,
-    "Ar": 39.948,
-    "Ca": 40.078,
-    "Sc": 44.9559,
-    "Ti": 47.867,
-    "V": 50.9415,
-    "Cr": 51.9961,
-    "Mn": 54.938,
-    "Fe": 55.845,
-    "Ni": 58.6934,
-    "Co": 58.9332,
-    "Cu": 63.546,
-    "Zn": 65.39,
-    "Ga": 69.723,
-    "Ge": 72.64,
-    "As": 74.9216,
-    "Se": 78.96,
-    "Br": 79.904,
-    "Kr": 83.8,
-    "Rb": 85.4678,
-    "Sr": 87.62,
-    "Y": 88.9059,
-    "Zr": 91.224,
-    "Nb": 92.9064,
-    "Mo": 95.94,
-    "Tc": 98,
-    "Ru": 101.07,
-    "Rh": 102.9055,
-    "Pd": 106.42,
-    "Ag": 107.8682,
-    "Cd": 112.411,
-    "In": 114.818,
-    "Sn": 118.71,
-    "Sb": 121.76,
-    "I": 126.9045,
-    "Te": 127.6,
-    "Xe": 131.293,
-    "Cs": 132.9055,
-    "Ba": 137.327,
-    "La": 138.9055,
-    "Ce": 140.116,
-    "Pr": 140.9077,
-    "Nd": 144.24,
-    "Pm": 145,
-    "Sm": 150.36,
-    "Eu": 151.964,
-    "Gd": 157.25,
-    "Tb": 158.9253,
-    "Dy": 162.5,
-    "Ho": 164.9303,
-    "Er": 167.259,
-    "Tm": 168.9342,
-    "Yb": 173.04,
-    "Lu": 174.967,
-    "Hf": 178.49,
-    "Ta": 180.9479,
-    "W": 183.84,
-    "Re": 186.207,
-    "Os": 190.23,
-    "Ir": 192.217,
-    "Pt": 195.078,
-    "Au": 196.9665,
-    "Hg": 200.59,
-    "Tl": 204.3833,
-    "Pb": 207.2,
-    "Bi": 208.9804,
-    "Po": 209,
-    "At": 210,
-    "Rn": 222,
-    "Fr": 223,
-    "Ra": 226,
-    "Ac": 227,
-    "Pa": 231.0359,
-    "Th": 232.0381,
-    "Np": 237,
-    "U": 238.0289,
-    "Am": 243,
-    "Pu": 244,
-    "Cm": 247,
-    "Bk": 247,
-    "Cf": 251,
-    "Es": 252,
-    "Fm": 257,
-    "Md": 258,
-    "No": 259,
-    "Rf": 261,
-    "Lr": 262,
-    "Db": 262,
-    "Bh": 264,
-    "Sg": 266,
-    "Mt": 268,
-    "Rg": 272,
-    "Hs": 277
+    "H": 1.0076, "He": 4.0026, "Li": 6.941, "Be": 9.0122, "B": 10.811,
+    "C": 12.0107, "N": 14.0067, "O": 15.9994, "F": 18.9984, "Ne": 20.1797,
+    "Na": 22.9897, "Mg": 24.305, "Al": 26.9815, "Si": 28.0855, "P": 30.9738,
+    "S": 32.065, "Cl": 35.453, "K": 39.0983, "Ar": 39.948, "Ca": 40.078,
+    "Sc": 44.9559, "Ti": 47.867, "V": 50.9415, "Cr": 51.9961, "Mn": 54.938,
+    "Fe": 55.845, "Ni": 58.6934, "Co": 58.9332, "Cu": 63.546, "Zn": 65.39,
+    "Ga": 69.723, "Ge": 72.64, "As": 74.9216, "Se": 78.96, "Br": 79.904,
+    "Kr": 83.8, "Rb": 85.4678, "Sr": 87.62, "Y": 88.9059, "Zr": 91.224,
+    "Nb": 92.9064, "Mo": 95.94, "Tc": 98, "Ru": 101.07, "Rh": 102.9055,
+    "Pd": 106.42, "Ag": 107.8682, "Cd": 112.411, "In": 114.818, "Sn": 118.71,
+    "Sb": 121.76, "I": 126.9045, "Te": 127.6, "Xe": 131.293, "Cs": 132.9055,
+    "Ba": 137.327, "La": 138.9055, "Ce": 140.116, "Pr": 140.9077, "Nd": 144.24,
+    "Pm": 145, "Sm": 150.36, "Eu": 151.964, "Gd": 157.25, "Tb": 158.9253,
+    "Dy": 162.5, "Ho": 164.9303, "Er": 167.259, "Tm": 168.9342, "Yb": 173.04,
+    "Lu": 174.967, "Hf": 178.49, "Ta": 180.9479, "W": 183.84, "Re": 186.207,
+    "Os": 190.23, "Ir": 192.217, "Pt": 195.078, "Au": 196.9665, "Hg": 200.59,
+    "Tl": 204.3833, "Pb": 207.2, "Bi": 208.9804, "Po": 209, "At": 210,
+    "Rn": 222, "Fr": 223, "Ra": 226, "Ac": 227, "Pa": 231.0359, "Th": 232.0381,
+    "Np": 237, "U": 238.0289, "Am": 243, "Pu": 244, "Cm": 247, "Bk": 247,
+    "Cf": 251, "Es": 252, "Fm": 257, "Md": 258, "No": 259, "Rf": 261,
+    "Lr": 262, "Db": 262, "Bh": 264, "Sg": 266, "Mt": 268, "Rg": 272, "Hs": 277
 }
 
 atom_lab_num = {"H": 1, "He": 2, "Li": 3, "Be": 4, "B": 5, "C": 6, "N": 7,
@@ -152,19 +63,67 @@ atom_lab_num = {"H": 1, "He": 2, "Li": 3, "Be": 4, "B": 5, "C": 6, "N": 7,
                 "Mt": 109, "Ds": 110, "Rg": 111, "Cn": 112, "Nh": 113,
                 "Fl": 114, "Mc": 115, "Lv": 116, "Ts": 117, "Og": 118}
 
-metals = ["Li", "Be", "Na", "Mg", "Al", "K", "Ca", "Sc", "Ti", "V",
-          "Cr", "Mn", "Fe", "Co", "Ni", "Cu", "Zn", "Ga", "Rb", "Sr",
-          "Y", "Zr", "Nb", "Mo", "Tc", "Ru", "Rh", "Pd", "Ag", "Cd",
-          "In", "Sn", "Cs", "Ba", "La", "Ce", "Pr", "Nd", "Pm", "Sm",
-          "Eu", "Gd", "Tb", "Dy", "Ho", "Er", "Tm", "Yb", "Lu", "Hf",
-          "Ta", "W", "Re", "Os", "Ir", "Pt", "Au", "Hg", "Tl", "Pb",
-          "Bi", "Po", "Fr", "Ra", "Ac", "Th", "Pa", "U", "Np", "Pu",
-          "Am", "Cm", "Bk", "Cf", "Es", "Fm", "Md", "No", "Lr", "Rf",
-          "Db", "Sg", "Bh", "Hs", "Mt", "Ds", "Rg", "Cn", "Nh", "Fl",
-          "Mc", "Lv"]
-
 atom_num_lab = dict(zip(atom_lab_num.values(), atom_lab_num.keys()))
 
+metals = [
+    "Li", "Be", "Na", "Mg", "Al", "K", "Ca", "Sc", "Ti", "V", "Cr", "Mn", "Fe",
+    "Co", "Ni", "Cu", "Zn", "Ga", "Rb", "Sr", "Y", "Zr", "Nb", "Mo", "Tc",
+    "Ru", "Rh", "Pd", "Ag", "Cd", "In", "Sn", "Cs", "Ba", "La", "Ce", "Pr",
+    "Nd", "Pm", "Sm", "Eu", "Gd", "Tb", "Dy", "Ho", "Er", "Tm", "Yb", "Lu",
+    "Hf", "Ta", "W", "Re", "Os", "Ir", "Pt", "Au", "Hg", "Tl", "Pb", "Bi",
+    "Po", "Fr", "Ra", "Ac", "Th", "Pa", "U", "Np", "Pu", "Am", "Cm", "Bk",
+    "Cf", "Es", "Fm", "Md", "No", "Lr", "Rf", "Db", "Sg", "Bh", "Hs", "Mt",
+    "Ds", "Rg", "Cn", "Nh", "Fl", "Mc", "Lv"
+]
+
+
+# Atomic radii
+# https://www.rsc.org/periodic-table/
+atomic_radii = {
+    "H": 1.1, "He": 1.4, "Li": 1.82, "Be": 1.53, "B": 1.92, "C": 1.7,
+    "N": 1.55, "O": 1.52, "F": 1.47, "Ne": 1.54, "Na": 2.27, "Mg": 1.73,
+    "Al": 1.84, "Si": 2.1, "P": 1.8, "S": 1.8, "Cl": 1.75, "Ar": 1.88,
+    "K": 2.75, "Ca": 2.31, "Sc": 2.15, "Ti": 2.11, "V": 2.07, "Cr": 2.06,
+    "Mn": 2.05, "Fe": 2.04, "Co": 2.0, "Ni": 1.97, "Cu": 1.96, "Zn": 2.01,
+    "Ga": 1.87, "Ge": 2.11, "As": 1.85, "Se": 1.9, "Br": 1.85, "Kr": 2.02,
+    "Rb": 3.03, "Sr": 2.49, "Y": 2.32, "Zr": 2.23, "Nb": 2.18, "Mo": 2.17,
+    "Tc": 2.16, "Ru": 2.13, "Rh": 2.1, "Pd": 2.1, "Ag": 2.11, "Cd": 2.18,
+    "In": 1.93, "Sn": 2.17, "Sb": 2.06, "Te": 2.06, "I": 1.98, "Xe": 2.16,
+    "Cs": 3.43, "Ba": 2.68, "La": 2.43, "Ce": 2.42, "Pr": 2.4, "Nd": 2.39,
+    "Pm": 2.38, "Sm": 2.36, "Eu": 2.35, "Gd": 2.34, "Tb": 2.33, "Dy": 2.31,
+    "Ho": 2.3, "Er": 2.29, "Tm": 2.27, "Yb": 2.26, "Lu": 2.24, "Hf": 2.23,
+    "Ta": 2.22, "W": 2.18, "Re": 2.16, "Os": 2.16, "Ir": 2.13, "Pt": 2.13,
+    "Au": 2.14, "Hg": 2.23, "Tl": 1.96, "Pb": 2.02, "Bi": 2.07, "Po": 1.97,
+    "At": 2.02, "Rn": 2.2, "Fr": 3.48, "Ra": 2.83, "Ac": 2.47, "Th": 2.45,
+    "Pa": 2.43, "U": 2.41, "Np": 2.39, "Pu": 2.43, "Am": 2.44, "Cm": 2.45,
+    "Bk": 2.44, "Cf": 2.45, "Es": 2.45, "Fm": 2.45, "Md": 2.46, "No": 2.46,
+    "Lr": 2.46
+}
+# Covalent radii
+# https://www.rsc.org/periodic-table/
+cov_radii = {
+    "H": 0.32, "He": 0.37, "Li": 1.3, "Be": 0.99, "B": 0.84, "C": 0.75,
+    "N": 0.71, "O": 0.64, "F": 0.6, "Ne": 0.62, "Na": 1.6, "Mg": 1.4,
+    "Al": 1.24, "Si": 1.14, "P": 1.09, "S": 1.04, "Cl": 1.0, "Ar": 1.01,
+    "K": 2.0, "Ca": 1.74, "Sc": 1.59, "Ti": 1.48, "V": 1.44, "Cr": 1.3,
+    "Mn": 1.29, "Fe": 1.24, "Co": 1.18, "Ni": 1.17, "Cu": 1.22, "Zn": 1.2,
+    "Ga": 1.23, "Ge": 1.2, "As": 1.2, "Se": 1.18, "Br": 1.17, "Kr": 1.16,
+    "Rb": 2.15, "Sr": 1.9, "Y": 1.76, "Zr": 1.64, "Nb": 1.56, "Mo": 1.46,
+    "Tc": 1.38, "Ru": 1.36, "Rh": 1.34, "Pd": 1.3, "Ag": 1.36, "Cd": 1.4,
+    "In": 1.42, "Sn": 1.4, "Sb": 1.4, "Te": 1.37, "I": 1.36, "Xe": 1.36,
+    "Cs": 2.38, "Ba": 2.06, "La": 1.94, "Ce": 1.84, "Pr": 1.9, "Nd": 1.88,
+    "Pm": 1.86, "Sm": 1.85, "Eu": 1.83, "Gd": 1.82, "Tb": 1.81, "Dy": 1.8,
+    "Ho": 1.79, "Er": 1.77, "Tm": 1.77, "Yb": 1.78, "Lu": 1.74, "Hf": 1.64,
+    "Ta": 1.58, "W": 1.5, "Re": 1.41, "Os": 1.36, "Ir": 1.32, "Pt": 1.3,
+    "Au": 1.3, "Hg": 1.32, "Tl": 1.44, "Pb": 1.45, "Bi": 1.5, "Po": 1.42,
+    "At": 1.48, "Rn": 1.46, "Fr": 2.42, "Ra": 2.11, "Ac": 2.01, "Th": 1.9,
+    "Pa": 1.84, "U": 1.83, "Np": 1.8, "Pu": 1.8, "Am": 1.73, "Cm": 1.68,
+    "Bk": 1.68, "Cf": 1.68, "Es": 1.65, "Fm": 1.67, "Md": 1.73, "No": 1.76,
+    "Lr": 1.61, "Rf": 1.57, "Db": 1.49, "Sg": 1.43, "Bh": 1.41, "Hs": 1.34,
+    "Mt": 1.29, "Ds": 1.28, "Rg": 1.21, "Cn": 1.22, "Nh": 1.36, "Fl": 1.43,
+    "Mc": 1.62, "Lv": 1.75, "Ts": 1.65, "Og": 1.57
+}
+
 
 def load_xyz(f_name: str, atomic_numbers: bool = False,
              add_indices: bool = False):
@@ -274,7 +233,7 @@ def save_xyz(f_name: str, labels: list, coords: np.ndarray,
     deprecated_in="4.2.0", removed_in="5.1.0", current_version=__version__,
     details="Use the remove_label_indices function instead"
 )
-def remove_numbers(labels: list):
+def remove_numbers(labels):
     """
     Remove numbers from a list of atomic labels
 
@@ -292,7 +251,7 @@ def remove_numbers(labels: list):
     return remove_label_indices(labels)
 
 
-def remove_label_indices(labels: list):
+def remove_label_indices(labels):
     """
     Remove label indexing from atomic symbols
     indexing is either numbers or numbers followed by letters:
@@ -328,7 +287,7 @@ def remove_label_indices(labels: list):
     deprecated_in="4.2.0", removed_in="5.1.0", current_version=__version__,
     details="Use the add_label_indices function instead"
 )
-def add_numbers(labels: list, style: str = 'per_element'):
+def add_numbers(labels, style='per_element'):
     """
     Add numbers to a list of atomic labels
 
@@ -350,7 +309,7 @@ def add_numbers(labels: list, style: str = 'per_element'):
     return add_label_indices(labels, style=style)
 
 
-def add_label_indices(labels: list, style: str = 'per_element'):
+def add_label_indices(labels, style='per_element'):
     """
     Add label indexing to atomic symbols - either element or per atom.
 
@@ -394,7 +353,7 @@ def add_label_indices(labels: list, style: str = 'per_element'):
     return labels_wn
 
 
-def count_n_atoms(form_str: str):
+def count_n_atoms(form_str):
     """
     Count number of atoms in a chemical formula
 
@@ -416,7 +375,7 @@ def count_n_atoms(form_str: str):
     return n_atoms
 
 
-def index_elements(labels: list, shift: int = 0):
+def index_elements(labels, shift=0):
     """
     Return dictionary of element (keys) and indices (values) from list
     of labels
@@ -447,7 +406,7 @@ def index_elements(labels: list, shift: int = 0):
     return ele_index
 
 
-def count_elements(labels: list):
+def count_elements(labels):
     """
     Count number of each element in a list of elements
 
@@ -474,7 +433,7 @@ def count_elements(labels: list):
     return ele_count
 
 
-def get_formula(labels: list):
+def get_formula(labels):
     """
     Generates empirical formula in alphabetical order given a list of labels
 
@@ -495,7 +454,7 @@ def get_formula(labels: list):
     return formula
 
 
-def formstr_to_formdict(form_str: str):
+def formstr_to_formdict(form_str):
     """
     Converts formula string into dictionary of {atomic label:quantity} pairs
 
@@ -521,7 +480,7 @@ def formstr_to_formdict(form_str: str):
     return form_dict
 
 
-def formdict_to_formstr(form_dict: dict, include_one: bool = False):
+def formdict_to_formstr(form_dict, include_one=False):
     """
     Converts dictionary of {atomic label:quantity} pairs into
     a single formula string in alphabetical order
@@ -568,7 +527,7 @@ def formdict_to_formstr(form_dict: dict, include_one: bool = False):
     return form_string
 
 
-def contains_metal(form_string: str):
+def contains_metal(form_string):
     """
     Indicates if a metal is found in a chemical formula string
 
@@ -592,8 +551,7 @@ def contains_metal(form_string: str):
     return metal_found
 
 
-def combine_xyz(labels_1: list, labels_2: list,
-                coords_1: list, coords_2: list):
+def combine_xyz(labels_1, labels_2, coords_1, coords_2):
     """
     Combine two sets of labels and coordinates
 
@@ -625,8 +583,7 @@ def combine_xyz(labels_1: list, labels_2: list,
     return labels, coords
 
 
-def get_neighborlist(labels: list, coords: np.ndarray,
-                     adjust_cutoff: dict = {}):
+def get_neighborlist(labels, coords, adjust_cutoff={}):
     """
     Calculate ASE neighbourlist based on covalent radii
 
@@ -661,9 +618,11 @@ def get_neighborlist(labels: list, coords: np.ndarray,
                 cutoffs[it] = adjust_cutoff[label]
 
     # Create neighbourlist using cutoffs
-    neigh_list = neighborlist.NeighborList(cutoffs=cutoffs,
-                                           self_interaction=False,
-                                           bothways=True)
+    neigh_list = neighborlist.NeighborList(
+        cutoffs=cutoffs,
+        self_interaction=False,
+        bothways=True
+    )
 
     # Update this list by specifying the atomic positions
     neigh_list.update(mol)
@@ -671,7 +630,7 @@ def get_neighborlist(labels: list, coords: np.ndarray,
     return neigh_list
 
 
-def get_adjacency(labels: list, coords: np.ndarray, adjust_cutoff: dict = {}):
+def get_adjacency(labels, coords, adjust_cutoff={}):
     """
     Calculate adjacency matrix using ASE based on covalent radii.
 
@@ -708,8 +667,7 @@ def get_adjacency(labels: list, coords: np.ndarray, adjust_cutoff: dict = {}):
     return adjacency
 
 
-def get_bonds(labels: list, coords: np.ndarray, neigh_list=None,
-              verbose: bool = True, style: str = 'indices'):
+def get_bonds(labels, coords, neigh_list=None, verbose=True, style='indices'):
     """
     Calculate list of atoms between which there is a bond.
     Using ASE. Only unique bonds are retained.
@@ -791,8 +749,7 @@ def get_bonds(labels: list, coords: np.ndarray, neigh_list=None,
     return bonds
 
 
-def get_angles(labels: list, coords: np.ndarray, neigh_list=None,
-               verbose: bool = True, style: str = 'indices'):
+def get_angles(labels, coords, neigh_list=None, verbose=True, style='indices'):
     """
     Calculate list of atoms between which there is a bond angle.
     Using ASE. Only unique angles are retained.
@@ -874,8 +831,8 @@ def get_angles(labels: list, coords: np.ndarray, neigh_list=None,
     return angles
 
 
-def get_dihedrals(labels: list, coords: np.ndarray, neigh_list=None,
-                  verbose: bool = True, style: str = 'indices'):
+def get_dihedrals(labels, coords, neigh_list=None, verbose=True,
+                  style='indices'):
     """
     Calculate and list of atoms between which there is a dihedral.
     Using ASE. Only unique dihedrals are retained.
@@ -962,7 +919,7 @@ def get_dihedrals(labels: list, coords: np.ndarray, neigh_list=None,
     return dihedrals
 
 
-def lab_to_num(labels: list):
+def lab_to_num(labels):
     """
     Convert atomic label to atomic number
 
@@ -984,7 +941,7 @@ def lab_to_num(labels: list):
     return numbers
 
 
-def num_to_lab(numbers: list, numbered: bool = True):
+def num_to_lab(numbers, numbered=True):
     """
     Convert atomic number to atomic labels
 
@@ -1011,7 +968,7 @@ def num_to_lab(numbers: list, numbered: bool = True):
     return labels_wn
 
 
-def reflect_coords(coords: np.ndarray):
+def reflect_coords(coords):
     """
     Reflect coordinates through xy plane
 
@@ -1052,7 +1009,7 @@ def reflect_coords(coords: np.ndarray):
     return coords
 
 
-def find_entities(labels: list, coords: np.ndarray, adjust_cutoff: dict = {}):
+def find_entities(labels, coords, adjust_cutoff={}):
     """
     Finds formulae of entities given in labels and coords using adjacency
     matrix
@@ -1129,11 +1086,9 @@ def find_entities(labels: list, coords: np.ndarray, adjust_cutoff: dict = {}):
     return dict(mol_indices)
 
 
-def remove_broken(labels: list, coords: np.ndarray, formulae: list,
-                  adjust_cutoff: dict = {}, verbose: bool = False,
-                  save: bool = False, frag_f_name: str = "fragments.xyz",
-                  clean_f_name: str = "clean.xyz",
-                  mask: list = [], skip: list = []):
+def remove_broken(labels, coords, formulae, adjust_cutoff={}, verbose=False,
+                  save=False, frag_f_name="fragments.xyz",
+                  clean_f_name="clean.xyz", mask=[], skip=[]):
     """
     Deprecated, use find_entities instead.
 
@@ -1184,7 +1139,7 @@ def remove_broken(labels: list, coords: np.ndarray, formulae: list,
     return
 
 
-def _calculate_rmsd(coords_1: np.ndarray, coords_2: np.ndarray):
+def _calculate_rmsd(coords_1, coords_2):
     """
     Calculates RMSD between two structures
     RMSD = sqrt(mean(deviations**2))
@@ -1221,9 +1176,8 @@ def _calculate_rmsd(coords_1: np.ndarray, coords_2: np.ndarray):
     return rmsd
 
 
-def calculate_rmsd(coords_1: np.ndarray, coords_2: np.ndarray,
-                   mask_1: list = [], mask_2: list = [], order_1: list = [],
-                   order_2: list = []):
+def calculate_rmsd(coords_1, coords_2, mask_1=[], mask_2=[], order_1=[],
+                   order_2=[]):
     """
     Calculates RMSD between two structures
     RMSD = sqrt(mean(deviations**2))
@@ -1284,7 +1238,7 @@ def calculate_rmsd(coords_1: np.ndarray, coords_2: np.ndarray,
     return rmsd
 
 
-def rotate_coords(coords: np.ndarray, alpha: float, beta: float, gamma: float):
+def rotate_coords(coords, alpha, beta, gamma):
     """
     Rotates coordinates by alpha, beta, gamma using the zyz convention
     https://easyspin.org/easyspin/documentation/eulerangles.html
@@ -1332,9 +1286,8 @@ def rotate_coords(coords: np.ndarray, alpha: float, beta: float, gamma: float):
     return rot_coords
 
 
-def minimise_rmsd(coords_1: np.ndarray, coords_2: np.ndarray,
-                  mask_1: list = [], mask_2: list = [], order_1: list = [],
-                  order_2: list = []):
+def minimise_rmsd(coords_1, coords_2, mask_1=[], mask_2=[], order_1=[],
+                  order_2=[]):
     """
     Minimising the RMSD between two structures
     If coords_1 and coords_2 are not the same length, then a mask array can be
@@ -1397,7 +1350,7 @@ def minimise_rmsd(coords_1: np.ndarray, coords_2: np.ndarray,
     return rmsd, alpha, beta, gamma
 
 
-def _rotate_and_rmsd(angs: list, coords_1: np.ndarray, coords_2: np.ndarray):
+def _rotate_and_rmsd(angs, coords_1, coords_2):
     """
     Rotates coords_1 by alpha, beta, gamma using the zyz convention
     https://easyspin.org/easyspin/documentation/eulerangles.html
